@@ -143,7 +143,7 @@ class Horde_Date
      * Default specs that are always supported.
      * @var string
      */
-    protected static $_defaultSpecs = '%CdDeHImMnRStTyY';
+    protected static $_defaultSpecs = '-%CdDeHImMnRStTyY';
 
     /**
      * Internally supported strftime() specifiers.
@@ -245,10 +245,9 @@ class Horde_Date
                 $this->_sec   = $parts['seconds'];
             }
         } else {
-            // Use date_create() so we can catch errors with PHP 5.2. Use
-            // "new DateTime() once we require 5.3.
-            $parsed = date_create($date);
-            if (!$parsed) {
+            try {
+                $parsed = new DateTime($date);
+            } catch (Exception $e) {
                 throw new Horde_Date_Exception(sprintf(Horde_Date_Translation::t("Failed to parse time string (%s)"), $date));
             }
             $parsed->setTimezone(new DateTimeZone(date_default_timezone_get()));
@@ -417,26 +416,29 @@ class Horde_Date
     /**
      * Getter for the date and time properties.
      *
-     * @param string $name  One of 'year', 'month', 'mday', 'hour', 'min' or
-     *                      'sec'.
+     * @param string $name  One of 'year', 'month', 'mday', 'hour', 'min',
+     *                      'sec' or 'timezone' (since Horde_Date 2.0.0).
      *
-     * @return integer  The property value, or null if not set.
+     * @return integer|string  The property value, or null if not set.
      */
     public function __get($name)
     {
         if ($name == 'day') {
             $name = 'mday';
         }
-
+        if ($name[0] == '_') {
+            return null;
+        }
         return $this->{'_' . $name};
     }
 
     /**
      * Setter for the date and time properties.
      *
-     * @param string $name    One of 'year', 'month', 'mday', 'hour', 'min' or
-     *                        'sec'.
-     * @param integer $value  The property value.
+     * @param string $name           One of 'year', 'month', 'mday', 'hour',
+     *                               'min', 'sec' or 'timezone' (since
+     *                               Horde_Date 2.0.0).
+     * @param integer|string $value  The property value.
      */
     public function __set($name, $value)
     {
@@ -444,6 +446,7 @@ class Horde_Date
             $this->_initializeTimezone($value);
             return;
         }
+
         if ($name == 'day') {
             $name = 'mday';
         }
@@ -896,17 +899,17 @@ class Horde_Date
             array('/%b/e',
                   '/%B/e',
                   '/%C/e',
-                  '/%d/e',
+                  '/%([-#]?)d/e',
                   '/%D/e',
                   '/%e/e',
-                  '/%H/e',
-                  '/%I/e',
-                  '/%m/e',
-                  '/%M/e',
+                  '/%([-#]?)H/e',
+                  '/%([-#]?)I/e',
+                  '/%([-#]?)m/e',
+                  '/%([-#]?)M/e',
                   '/%n/',
                   '/%p/e',
                   '/%R/e',
-                  '/%S/e',
+                  '/%([-#]?)S/e',
                   '/%t/',
                   '/%T/e',
                   '/%x/e',
@@ -914,24 +917,24 @@ class Horde_Date
                   '/%y/e',
                   '/%Y/',
                   '/%%/'),
-            array('$this->_strftime(Horde_Nls::getLangInfo(constant(\'ABMON_\' . (int)$this->_month)))',
-                  '$this->_strftime(Horde_Nls::getLangInfo(constant(\'MON_\' . (int)$this->_month)))',
+            array('$this->strftime(Horde_Nls::getLangInfo(constant(\'ABMON_\' . (int)$this->_month)))',
+                  '$this->strftime(Horde_Nls::getLangInfo(constant(\'MON_\' . (int)$this->_month)))',
                   '(int)($this->_year / 100)',
-                  'sprintf(\'%02d\', $this->_mday)',
-                  '$this->_strftime(\'%m/%d/%y\')',
+                  'sprintf(\'%\' . (\'$1\' ? \'\' : \'02\') . \'d\', $this->_mday)',
+                  '$this->strftime(\'%m/%d/%y\')',
                   'sprintf(\'%2d\', $this->_mday)',
-                  'sprintf(\'%02d\', $this->_hour)',
-                  'sprintf(\'%02d\', $this->_hour == 0 ? 12 : ($this->_hour > 12 ? $this->_hour - 12 : $this->_hour))',
-                  'sprintf(\'%02d\', $this->_month)',
-                  'sprintf(\'%02d\', $this->_min)',
+                  'sprintf(\'%\' . (\'$1\' ? \'\' : \'02\') . \'d\', $this->_hour)',
+                  'sprintf(\'%\' . (\'$1\' ? \'\' : \'02\') . \'d\', $this->_hour == 0 ? 12 : ($this->_hour > 12 ? $this->_hour - 12 : $this->_hour))',
+                  'sprintf(\'%\' . (\'$1\' ? \'\' : \'02\') . \'d\', $this->_month)',
+                  'sprintf(\'%\' . (\'$1\' ? \'\' : \'02\') . \'d\', $this->_min)',
                   "\n",
-                  '$this->_strftime(Horde_Nls::getLangInfo($this->_hour < 12 ? AM_STR : PM_STR))',
-                  '$this->_strftime(\'%H:%M\')',
-                  'sprintf(\'%02d\', $this->_sec)',
+                  '$this->strftime(Horde_Nls::getLangInfo($this->_hour < 12 ? AM_STR : PM_STR))',
+                  '$this->strftime(\'%H:%M\')',
+                  'sprintf(\'%\' . (\'$1\' ? \'\' : \'02\') . \'d\', $this->_sec)',
                   "\t",
-                  '$this->_strftime(\'%H:%M:%S\')',
-                  '$this->_strftime(Horde_Nls::getLangInfo(D_FMT))',
-                  '$this->_strftime(Horde_Nls::getLangInfo(T_FMT))',
+                  '$this->strftime(\'%H:%M:%S\')',
+                  '$this->strftime(Horde_Nls::getLangInfo(D_FMT))',
+                  '$this->strftime(Horde_Nls::getLangInfo(T_FMT))',
                   'substr(sprintf(\'%04d\', $this->_year), -2)',
                   (int)$this->_year,
                   '%'),
